/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.sling.taglib;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import com.squeakysand.commons.lang.StringUtils;
import com.squeakysand.jsp.tagext.BodyContent;
import com.squeakysand.jsp.tagext.annotations.JspTag;
import com.squeakysand.jsp.tagext.annotations.JspTagAttribute;
import com.squeakysand.sling.SlingUtils;

import org.apache.sling.api.SlingHttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@JspTag(bodyContent = BodyContent.SCRIPTLESS)
public class IfSelectorTag extends SlingSimpleTagSupport {

    private static final Logger LOG = LoggerFactory.getLogger(IfSelectorTag.class);
    private String isNotPresent;
    private String isPresent;

    @Override
    public void doTag() throws JspException, IOException {
        SlingHttpServletRequest slingRequest = (SlingHttpServletRequest) getRequest();
        if (StringUtils.isNotNullOrEmpty(isPresent)) {
            Boolean isSelectorPresent = SlingUtils.isSelectorPresent(isPresent, slingRequest);
            if (isSelectorPresent) {
                getJspBody().invoke(null);
            }
        } else if (StringUtils.isNotNullOrEmpty(isNotPresent)) {
            Boolean isSelectorNotPresent = !SlingUtils.isSelectorPresent(isNotPresent, slingRequest);
            if (isSelectorNotPresent) {
                getJspBody().invoke(null);
            }
        } else {
            throw new JspException("one of isPresent or isNotPresent must be set");
        }
    }

    public String getIsNotPresent() {
        return isNotPresent;
    }

    public String getIsPresent() {
        return isPresent;
    }

    @JspTagAttribute(rtexprvalue = true)
    public void setIsNotPresent(String selectorName) {
        this.isNotPresent = selectorName;
    }

    @JspTagAttribute(rtexprvalue = true)
    public void setIsPresent(String selectorName) {
        this.isPresent = selectorName;
    }

}
